==> open-cluster-management-apps-model-6.9.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/HelmAppStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HelmAppStatusFluent<A extends HelmAppStatusFluent<A>> extends BaseFluent<A>{
  public HelmAppStatusFluent() {
  }
  
  public HelmAppStatusFluent(HelmAppStatus instance) {
    this.copyInstance(instance);
  }
  private ArrayList<HelmAppConditionBuilder> conditions = new ArrayList<HelmAppConditionBuilder>();
  private HelmAppReleaseBuilder deployedRelease;
  
  protected void copyInstance(HelmAppStatus instance) {
    instance = (instance != null ? instance : new HelmAppStatus());
    if (instance != null) {
          this.withConditions(instance.getConditions());
          this.withDeployedRelease(instance.getDeployedRelease());
          this.withConditions(instance.getConditions());
          this.withDeployedRelease(instance.getDeployedRelease());
        }
  }
  
  public A addToConditions(int index,HelmAppCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<HelmAppConditionBuilder>();}
    HelmAppConditionBuilder builder = new HelmAppConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").add(index, builder); conditions.add(index, builder);}
    return (A)this;
  }
  
  public A setToConditions(int index,HelmAppCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<HelmAppConditionBuilder>();}
    HelmAppConditionBuilder builder = new HelmAppConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").set(index, builder); conditions.set(index, builder);}
    return (A)this;
  }
  
  public A addToConditions(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmAppCondition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<HelmAppConditionBuilder>();}
    for (HelmAppCondition item : items) {HelmAppConditionBuilder builder = new HelmAppConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A addAllToConditions(Collection<HelmAppCondition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<HelmAppConditionBuilder>();}
    for (HelmAppCondition item : items) {HelmAppConditionBuilder builder = new HelmAppConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A removeFromConditions(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmAppCondition... items) {
    if (this.conditions == null) return (A)this;
    for (HelmAppCondition item : items) {HelmAppConditionBuilder builder = new HelmAppConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeAllFromConditions(Collection<HelmAppCondition> items) {
    if (this.conditions == null) return (A)this;
    for (HelmAppCondition item : items) {HelmAppConditionBuilder builder = new HelmAppConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromConditions(Predicate<HelmAppConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<HelmAppConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      HelmAppConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<HelmAppCondition> buildConditions() {
    return this.conditions != null ? build(conditions) : null;
  }
  
  public HelmAppCondition buildCondition(int index) {
    return this.conditions.get(index).build();
  }
  
  public HelmAppCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  
  public HelmAppCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  
  public HelmAppCondition buildMatchingCondition(Predicate<HelmAppConditionBuilder> predicate) {
      for (HelmAppConditionBuilder item : conditions) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingCondition(Predicate<HelmAppConditionBuilder> predicate) {
      for (HelmAppConditionBuilder item : conditions) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withConditions(List<HelmAppCondition> conditions) {
    if (this.conditions != null) {
      this._visitables.get("conditions").clear();
    }
    if (conditions != null) {
        this.conditions = new ArrayList();
        for (HelmAppCondition item : conditions) {
          this.addToConditions(item);
        }
    } else {
      this.conditions = null;
    }
    return (A) this;
  }
  
  public A withConditions(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmAppCondition... conditions) {
    if (this.conditions != null) {this.conditions.clear(); _visitables.remove("conditions"); }
    if (conditions != null) {for (HelmAppCondition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  
  public boolean hasConditions() {
    return this.conditions != null && !this.conditions.isEmpty();
  }
  
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type) {
    return (A)addToConditions(new HelmAppCondition(lastTransitionTime, message, reason, status, type));
  }
  
  public ConditionsNested<A> addNewCondition() {
    return new ConditionsNested(-1, null);
  }
  
  public ConditionsNested<A> addNewConditionLike(HelmAppCondition item) {
    return new ConditionsNested(-1, item);
  }
  
  public ConditionsNested<A> setNewConditionLike(int index,HelmAppCondition item) {
    return new ConditionsNested(index, item);
  }
  
  public ConditionsNested<A> editCondition(int index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  
  public ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editMatchingCondition(Predicate<HelmAppConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public HelmAppRelease buildDeployedRelease() {
    return this.deployedRelease != null ? this.deployedRelease.build() : null;
  }
  
  public A withDeployedRelease(HelmAppRelease deployedRelease) {
    this._visitables.remove(this.deployedRelease);
    if (deployedRelease != null) {
        this.deployedRelease = new HelmAppReleaseBuilder(deployedRelease);
        this._visitables.get("deployedRelease").add(this.deployedRelease);
    } else {
        this.deployedRelease = null;
        this._visitables.get("deployedRelease").remove(this.deployedRelease);
    }
    return (A) this;
  }
  
  public boolean hasDeployedRelease() {
    return this.deployedRelease != null;
  }
  
  public A withNewDeployedRelease(String manifest,String name) {
    return (A)withDeployedRelease(new HelmAppRelease(manifest, name));
  }
  
  public DeployedReleaseNested<A> withNewDeployedRelease() {
    return new DeployedReleaseNested(null);
  }
  
  public DeployedReleaseNested<A> withNewDeployedReleaseLike(HelmAppRelease item) {
    return new DeployedReleaseNested(item);
  }
  
  public DeployedReleaseNested<A> editDeployedRelease() {
    return withNewDeployedReleaseLike(java.util.Optional.ofNullable(buildDeployedRelease()).orElse(null));
  }
  
  public DeployedReleaseNested<A> editOrNewDeployedRelease() {
    return withNewDeployedReleaseLike(java.util.Optional.ofNullable(buildDeployedRelease()).orElse(new HelmAppReleaseBuilder().build()));
  }
  
  public DeployedReleaseNested<A> editOrNewDeployedReleaseLike(HelmAppRelease item) {
    return withNewDeployedReleaseLike(java.util.Optional.ofNullable(buildDeployedRelease()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HelmAppStatusFluent that = (HelmAppStatusFluent) o;
    if (!java.util.Objects.equals(conditions, that.conditions)) return false;
    if (!java.util.Objects.equals(deployedRelease, that.deployedRelease)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(conditions,  deployedRelease,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (deployedRelease != null) { sb.append("deployedRelease:"); sb.append(deployedRelease); }
    sb.append("}");
    return sb.toString();
  }
  public class ConditionsNested<N> extends HelmAppConditionFluent<ConditionsNested<N>> implements Nested<N>{
    ConditionsNested(int index,HelmAppCondition item) {
      this.index = index;
      this.builder = new HelmAppConditionBuilder(this, item);
    }
    HelmAppConditionBuilder builder;
    int index;
    
    public N and() {
      return (N) HelmAppStatusFluent.this.setToConditions(index,builder.build());
    }
    
    public N endCondition() {
      return and();
    }
    
  
  }
  public class DeployedReleaseNested<N> extends HelmAppReleaseFluent<DeployedReleaseNested<N>> implements Nested<N>{
    DeployedReleaseNested(HelmAppRelease item) {
      this.builder = new HelmAppReleaseBuilder(this, item);
    }
    HelmAppReleaseBuilder builder;
    
    public N and() {
      return (N) HelmAppStatusFluent.this.withDeployedRelease(builder.build());
    }
    
    public N endDeployedRelease() {
      return and();
    }
    
  
  }

}

==> open-cluster-management-apps-model-6.13.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/HelmAppStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HelmAppStatusFluent<A extends HelmAppStatusFluent<A>> extends BaseFluent<A>{
  public HelmAppStatusFluent() {
  }
  
  public HelmAppStatusFluent(HelmAppStatus instance) {
    this.copyInstance(instance);
  }
  private ArrayList<HelmAppConditionBuilder> conditions = new ArrayList<HelmAppConditionBuilder>();
  private HelmAppReleaseBuilder deployedRelease;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(HelmAppStatus instance) {
    instance = (instance != null ? instance : new HelmAppStatus());
    if (instance != null) {
          this.withConditions(instance.getConditions());
          this.withDeployedRelease(instance.getDeployedRelease());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToConditions(int index,HelmAppCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<HelmAppConditionBuilder>();}
    HelmAppConditionBuilder builder = new HelmAppConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").add(index, builder); conditions.add(index, builder);}
    return (A)this;
  }
  
  public A setToConditions(int index,HelmAppCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<HelmAppConditionBuilder>();}
    HelmAppConditionBuilder builder = new HelmAppConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").set(index, builder); conditions.set(index, builder);}
    return (A)this;
  }
  
  public A addToConditions(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmAppCondition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<HelmAppConditionBuilder>();}
    for (HelmAppCondition item : items) {HelmAppConditionBuilder builder = new HelmAppConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A addAllToConditions(Collection<HelmAppCondition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<HelmAppConditionBuilder>();}
    for (HelmAppCondition item : items) {HelmAppConditionBuilder builder = new HelmAppConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  
  public A removeFromConditions(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmAppCondition... items) {
    if (this.conditions == null) return (A)this;
    for (HelmAppCondition item : items) {HelmAppConditionBuilder builder = new HelmAppConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeAllFromConditions(Collection<HelmAppCondition> items) {
    if (this.conditions == null) return (A)this;
    for (HelmAppCondition item : items) {HelmAppConditionBuilder builder = new HelmAppConditionBuilder(item);_visitables.get("conditions").remove(builder); this.conditions.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromConditions(Predicate<HelmAppConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<HelmAppConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      HelmAppConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<HelmAppCondition> buildConditions() {
    return this.conditions != null ? build(conditions) : null;
  }
  
  public HelmAppCondition buildCondition(int index) {
    return this.conditions.get(index).build();
  }
  
  public HelmAppCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  
  public HelmAppCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  
  public HelmAppCondition buildMatchingCondition(Predicate<HelmAppConditionBuilder> predicate) {
      for (HelmAppConditionBuilder item : conditions) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingCondition(Predicate<HelmAppConditionBuilder> predicate) {
      for (HelmAppConditionBuilder item : conditions) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withConditions(List<HelmAppCondition> conditions) {
    if (this.conditions != null) {
      this._visitables.get("conditions").clear();
    }
    if (conditions != null) {
        this.conditions = new ArrayList();
        for (HelmAppCondition item : conditions) {
          this.addToConditions(item);
        }
    } else {
      this.conditions = null;
    }
    return (A) this;
  }
  
  public A withConditions(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmAppCondition... conditions) {
    if (this.conditions != null) {
        this.conditions.clear();
        _visitables.remove("conditions");
    }
    if (conditions != null) {
      for (HelmAppCondition item : conditions) {
        this.addToConditions(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasConditions() {
    return this.conditions != null && !this.conditions.isEmpty();
  }
  
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type) {
    return (A)addToConditions(new HelmAppCondition(lastTransitionTime, message, reason, status, type));
  }
  
  public ConditionsNested<A> addNewCondition() {
    return new ConditionsNested(-1, null);
  }
  
  public ConditionsNested<A> addNewConditionLike(HelmAppCondition item) {
    return new ConditionsNested(-1, item);
  }
  
  public ConditionsNested<A> setNewConditionLike(int index,HelmAppCondition item) {
    return new ConditionsNested(index, item);
  }
  
  public ConditionsNested<A> editCondition(int index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  
  public ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public ConditionsNested<A> editMatchingCondition(Predicate<HelmAppConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  
  public HelmAppRelease buildDeployedRelease() {
    return this.deployedRelease != null ? this.deployedRelease.build() : null;
  }
  
  public A withDeployedRelease(HelmAppRelease deployedRelease) {
    this._visitables.remove("deployedRelease");
    if (deployedRelease != null) {
        this.deployedRelease = new HelmAppReleaseBuilder(deployedRelease);
        this._visitables.get("deployedRelease").add(this.deployedRelease);
    } else {
        this.deployedRelease = null;
        this._visitables.get("deployedRelease").remove(this.deployedRelease);
    }
    return (A) this;
  }
  
  public boolean hasDeployedRelease() {
    return this.deployedRelease != null;
  }
  
  public A withNewDeployedRelease(String manifest,String name) {
    return (A)withDeployedRelease(new HelmAppRelease(manifest, name));
  }
  
  public DeployedReleaseNested<A> withNewDeployedRelease() {
    return new DeployedReleaseNested(null);
  }
  
  public DeployedReleaseNested<A> withNewDeployedReleaseLike(HelmAppRelease item) {
    return new DeployedReleaseNested(item);
  }
  
  public DeployedReleaseNested<A> editDeployedRelease() {
    return withNewDeployedReleaseLike(java.util.Optional.ofNullable(buildDeployedRelease()).orElse(null));
  }
  
  public DeployedReleaseNested<A> editOrNewDeployedRelease() {
    return withNewDeployedReleaseLike(java.util.Optional.ofNullable(buildDeployedRelease()).orElse(new HelmAppReleaseBuilder().build()));
  }
  
  public DeployedReleaseNested<A> editOrNewDeployedReleaseLike(HelmAppRelease item) {
    return withNewDeployedReleaseLike(java.util.Optional.ofNullable(buildDeployedRelease()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HelmAppStatusFluent that = (HelmAppStatusFluent) o;
    if (!java.util.Objects.equals(conditions, that.conditions)) return false;
    if (!java.util.Objects.equals(deployedRelease, that.deployedRelease)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(conditions,  deployedRelease,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (deployedRelease != null) { sb.append("deployedRelease:"); sb.append(deployedRelease + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ConditionsNested<N> extends HelmAppConditionFluent<ConditionsNested<N>> implements Nested<N>{
    ConditionsNested(int index,HelmAppCondition item) {
      this.index = index;
      this.builder = new HelmAppConditionBuilder(this, item);
    }
    HelmAppConditionBuilder builder;
    int index;
    
    public N and() {
      return (N) HelmAppStatusFluent.this.setToConditions(index,builder.build());
    }
    
    public N endCondition() {
      return and();
    }
    
  
  }
  public class DeployedReleaseNested<N> extends HelmAppReleaseFluent<DeployedReleaseNested<N>> implements Nested<N>{
    DeployedReleaseNested(HelmAppRelease item) {
      this.builder = new HelmAppReleaseBuilder(this, item);
    }
    HelmAppReleaseBuilder builder;
    
    public N and() {
      return (N) HelmAppStatusFluent.this.withDeployedRelease(builder.build());
    }
    
    public N endDeployedRelease() {
      return and();
    }
    
  
  }

}
